list_contexts_handler

Function list_contexts_handler 

pub async fn list_contexts_handler(
    __arg0: State<Arc<NodeState>>,
) -> impl IntoResponse
Handler for GET /scp/dev/v1/contexts.

Returns a JSON array of all registered broadcast contexts as ContextResponse values. Returns an empty array when no contexts are registered.

See spec section 18.10.3.