pub fn validate_projection_policy(
admission: BroadcastAdmission,
policy: Option<&ProjectionPolicy>,
) -> Result<(), String>Expand description
Validates that a projection policy is consistent with the context’s admission mode.
Gated contexts cannot have ProjectionRule::Public as the default rule
or in any per-author override, because that would allow unauthenticated
access to content that the context’s admission mode requires
authentication for (spec section 18.11.2.1).
Errors
Returns an error message if a gated context has a Public default
projection rule or a Public per-author override.