FeedResponse

Struct FeedResponse 

pub struct FeedResponse {
    pub context_id: String,
    pub author_did: String,
    pub messages: Vec<FeedMessage>,
}
JSON response body for GET /scp/broadcast/<routing_id>/feed.

Contains the context ID, the primary author DID (from the first message in the response, or the projected context’s author), and an array of decrypted broadcast messages.

See spec section 18.11.3.

Fields

context_id: String

The hex-encoded context ID that this feed belongs to.

author_did: String

The DID of the broadcast context’s primary author.

Derived from the first message in the response. If no messages are present, this is an empty string.

messages: Vec<FeedMessage>

Array of decrypted broadcast messages, ordered oldest-first.