pub struct RelayHandle { /* private fields */ }Expand description
Handle to the running relay server.
Wraps the bound address, shutdown handle, and provides access to the relay’s state. The relay accepts connections from any SCP client (spec section 18.6.4).
Implementations
Sourceimpl RelayHandle
impl RelayHandle
Sourcepub const fn bound_addr(&self) -> SocketAddr
pub const fn bound_addr(&self) -> SocketAddr
Returns the local address the relay server is bound to.
Sourcepub const fn shutdown_handle(&self) -> &ShutdownHandle
pub const fn shutdown_handle(&self) -> &ShutdownHandle
Returns a reference to the relay’s shutdown handle.